@@ -33,7 +33,7 @@
 
 QTEST_GUILESS_MAIN(AlternativesModelTest)
 
-int saveAsRow(Purpose::AlternativesModel* model)
+static int saveAsRow(Purpose::AlternativesModel* model)
 {
     for(int i=0, c=model->rowCount(); i<c; ++i) {
         QString pluginId = model->index(i).data(Purpose::AlternativesModel::PluginIdRole).toString();
@@ -46,11 +46,23 @@ int saveAsRow(Purpose::AlternativesModel* model)
     return -1;
 }
 
+void AlternativesModelTest::initTestCase()
+{
+    // To avoid a runtime dependency on klauncher
+    qputenv("KDE_FORK_SLAVES", "yes");
+
+    if (qEnvironmentVariableIsSet("QT_LOGGING_RULES")) { // as is the case in CI
+        // CopyJob debug output is too noisy because of the huge data URL we're using in bigBufferTest.
+        qputenv("QT_LOGGING_RULES", qgetenv("QT_LOGGING_RULES") + QByteArrayLiteral(";kf5.kio.core.copyjob.debug=false"));
+    }
+
+}
+
 void AlternativesModelTest::runJobTest()
 {
     Purpose::AlternativesModel model;
 
-    const QString tempfile = QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QStringLiteral("/purposetest");
+    const QString tempfile = m_tempDir.path() + QStringLiteral("/purposetest");
     QFile::remove(tempfile);
     QJsonObject input = QJsonObject {
         {QStringLiteral("urls"), QJsonArray {QStringLiteral("http://kde.org")} },
@@ -83,14 +95,12 @@ void AlternativesModelTest::runJobTest()
 
 void AlternativesModelTest::bigBufferTest()
 {
-    QLoggingCategory::setFilterRules(QStringLiteral("kf5.kio.core.copyjob=false"));
-
     Purpose::AlternativesModel model;
 
     const QByteArray payload(1920*1080*4, 'x');
     const QString uri = QStringLiteral("data:text/plain;base64,") + QString::fromLatin1(payload.toBase64());
 
-    const QString tempfile = QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QStringLiteral("/purposetest");
+    const QString tempfile = m_tempDir.path() + QStringLiteral("/purposetest");
     QFile::remove(tempfile);
     const QJsonObject input = {
         {QStringLiteral("urls"), QJsonArray {uri} },
